@@ -68,17 +68,6 @@ ImportWorker::~ImportWorker()
         qDebug() << "Function Name: " << Q_FUNC_INFO << " Destructor from Worker thread: " << QThread::currentThread();
         disconnect(this, &ImportWorker::not_a_number, Q_NULLPTR, Q_NULLPTR);
         disconnect(this, &ImportWorker::not_valid_payment, Q_NULLPTR, Q_NULLPTR);
-
-        /*
-        if (dbc.driverName() == "QSQLITE") {
-            CSqlQuery query(dbc, Q_FUNC_INFO);
-            query.exec("PRAGMA wal_checkpoint;");
-            query.next();
-            qDebug() << "Function Name: " << Q_FUNC_INFO << "WAL Checkpoint: (busy:"
-        << query.value(0).toString() << ") log: " << query.value(1).toString() << "
-        checkpointed: " << query.value(2).toString();
-        }
-        */
     }
     DatabaseManager::removeCurrentThread("CN");
 }
@@ -316,9 +305,9 @@ bool ImportWorker::importR2B(QJsonObject data)
     ;
     if (!ok) {
         emit database_error(QString("Transaction failed(%1), %2 %3")
-                                .arg(ok)
-                                .arg(dbc.lastError().text())
-                                .arg(dbc.lastError().nativeErrorCode()));
+                .arg(ok)
+                .arg(dbc.lastError().text())
+                .arg(dbc.lastError().nativeErrorCode()));
         return ok;
     }
 
@@ -364,9 +353,9 @@ bool ImportWorker::importR2B(QJsonObject data)
         qDebug() << "Function Name: " << Q_FUNC_INFO << " transaction rollback: " << m_transaction;
         m_transaction--;
         emit database_error(QString("Rollback = %1,%2 %3")
-                                .arg(sql_ok)
-                                .arg(dbc.lastError().text())
-                                .arg(dbc.lastError().nativeErrorCode()));
+                .arg(sql_ok)
+                .arg(dbc.lastError().text())
+                .arg(dbc.lastError().nativeErrorCode()));
     }
 
     return ok;
@@ -383,9 +372,9 @@ bool ImportWorker::importReceipt(QJsonObject data)
     qDebug() << "Function Name: " << Q_FUNC_INFO << " transaction start: " << m_transaction;
     if (!ok) {
         emit database_error(QString("Transaction failed(%1), %2 %3")
-                                .arg(ok)
-                                .arg(dbc.lastError().text())
-                                .arg(dbc.lastError().nativeErrorCode()));
+                .arg(ok)
+                .arg(dbc.lastError().text())
+                .arg(dbc.lastError().nativeErrorCode()));
         return ok;
     }
 
@@ -425,9 +414,9 @@ bool ImportWorker::importReceipt(QJsonObject data)
         qDebug() << "Function Name: " << Q_FUNC_INFO << " transaction rollback: " << m_transaction;
         m_transaction--;
         emit database_error(QString("Rollback = %1,%2 %3")
-                                .arg(sql_ok)
-                                .arg(dbc.lastError().text())
-                                .arg(dbc.lastError().nativeErrorCode()));
+                .arg(sql_ok)
+                .arg(dbc.lastError().text())
+                .arg(dbc.lastError().nativeErrorCode()));
     }
 
     return ok;
